@@ -96,17 +96,7 @@ def schema_list():
     """Print the full database schema"""
 
     for table in (
-        crossref.tables
-        + [
-            csv_sources.asjc_table,
-            csv_sources.asjc_general_fields_table,
-            csv_sources.funders_table,
-            csv_sources.journals_table,
-            csv_sources.journals_issns_table,
-            csv_sources.open_access_table,
-        ]
-        + orcid.tables
-        + ror.tables
+        crossref.tables + csv_sources.tables + orcid.tables + ror.tables
     ):
         print(table.table_schema())
 
@@ -156,11 +146,8 @@ def database_counts(database):
     print(f"{count} references(s) with DOI")
 
 
-def parse_cli_arguments(args=None):
+def parse_cli_arguments(parser, args=None):
     """Parse command line arguments (or args e.g. when testing)"""
-    parser = argparse.ArgumentParser(
-        description="alexandria3k: Publication metadata interface"
-    )
 
     parser.add_argument(
         "-c",
@@ -303,10 +290,10 @@ def parse_cli_arguments(args=None):
         "--execute",
         type=str,
         help="""Operation to execute on the data. This can be one of:
-link-base-ror-aa (link base-level research organizations with author
-affiliations);
-link-top-ror-aa (link top-level research organizations with author
-affiliations)
+link-aa-base-ror (link author affiliations to base-level research
+organizations);
+link-aa-top-ror (link author affiliations to top-level research organizations);
+link-works-asjcs (link works with Scopus All Science Journal Classification Codes — ASJCs).
         """,
     )
 
@@ -380,7 +367,10 @@ def main():
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-statements
     """Program entry point"""
-    args = parse_cli_arguments()
+    parser = argparse.ArgumentParser(
+        description="alexandria3k: Publication metadata interface"
+    )
+    args = parse_cli_arguments(parser)
 
     # Setup debug logging and performance monitoring
     debug.set_flags(args.debug)
@@ -474,10 +464,14 @@ def main():
             args.populate_db_path, args.journal_names
         )
 
-    if args.execute == "link-base-ror-aa":
+    if args.execute == "link-aa-base-ror":
         ror.link_author_affiliations(args.populate_db_path, link_to_top=False)
-    elif args.execute == "link-top-ror-aa":
+    elif args.execute == "link-aa-top-ror":
         ror.link_author_affiliations(args.populate_db_path, link_to_top=True)
+    elif args.execute == "link-works-asjcs":
+        csv_sources.link_works_asjcs(args.populate_db_path)
+    elif args.execute:
+        parser.error(f"Unknown execution argument: {args.execute}")
 
     if debug.enabled("populated-counts"):
         populated_db = sqlite3.connect(args.populate_db_path)
