@@ -22,7 +22,8 @@ import codecs
 import csv
 import sqlite3
 
-from .common import data_source, get_string_resource
+from .common import data_source, ensure_table_exists, get_string_resource
+from . import perf
 from .virtual_db import ColumnMeta, TableMeta
 
 
@@ -217,12 +218,22 @@ open_access_table = TableMeta(
 
 # Scopus Subject Areas and All Science Journal Classification Codes (ASJC)
 # https://service.elsevier.com/app/answers/detail/a_id/15181/supporthub/scopus/
-asjc_table = TableMeta(
-    "asjc",
+asjc_import_table = TableMeta(
+    "asjc_import",
     columns=[
         ColumnMeta("id"),
         ColumnMeta("field"),
         ColumnMeta("subject_area"),
+    ],
+    post_population_script="sql/normalize-asjc.sql",
+)
+
+asjcs_table = TableMeta(
+    "asjcs",
+    columns=[
+        ColumnMeta("id"),
+        ColumnMeta("field"),
+        ColumnMeta("subject_area_id"),
         ColumnMeta("general_field_id"),
     ],
     post_population_script="sql/normalize-asjc.sql",
@@ -236,6 +247,33 @@ asjc_general_fields_table = TableMeta(
     ],
 )
 
+asjc_subject_areas_table = TableMeta(
+    "asjc_subject_areas",
+    columns=[
+        ColumnMeta("id"),
+        ColumnMeta("name"),
+    ],
+)
+
+works_asjcs_table = TableMeta(
+    "works_asjcs",
+    columns=[
+        ColumnMeta("work_id"),
+        ColumnMeta("asjc_id"),
+    ],
+)
+
+tables = [
+    asjc_general_fields_table,
+    asjc_subject_areas_table,
+    asjcs_table,
+    funders_table,
+    journals_issns_table,
+    journals_table,
+    open_access_table,
+    works_asjcs_table,
+]
+
 
 def load_csv_data(database_path, table_meta, source, delimiter=","):
     """Populate specified table of database with data from source"""
@@ -246,17 +284,19 @@ def load_csv_data(database_path, table_meta, source, delimiter=","):
     cur.executemany(
         table_meta.insert_statement(), record_source(source, delimiter)
     )
+    perf.log("Load CSV data")
     post_population_script = table_meta.get_post_population_script()
     if post_population_script:
         script = get_string_resource(post_population_script)
         cur.executescript(script)
+        perf.log(f"Run {post_population_script}")
     con.commit()
     con.close()
 
 
 def populate_asjc(database_path, source):
     """Populate ASJC table of database with data from source"""
-    load_csv_data(database_path, asjc_table, source, delimiter=";")
+    load_csv_data(database_path, asjc_import_table, source, delimiter=";")
 
 
 def populate_journal_names(database_path, source):
@@ -272,3 +312,15 @@ def populate_funder_names(database_path, source):
 def populate_open_access_journals(database_path, source):
     """Populate OA journals table of database with data from source"""
     load_csv_data(database_path, open_access_table, source)
+
+
+def link_works_asjcs(database_path):
+    """Create a many to many table linking works with Scopus
+    All Science Journal Classification Codes — ASJCs"""
+    connection = sqlite3.connect(database_path)
+    ensure_table_exists(connection, "work_subjects")
+    ensure_table_exists(connection, "asjcs")
+    script = get_string_resource("sql/link-works-asjcs.sql")
+    cursor = connection.cursor()
+    cursor.executescript(script)
+    perf.log("link_works_asjcs")
